@@ -17,23 +17,22 @@ hitch_conf = <<~EOF
   }
 EOF
 
-context "When configuration and certificate is present" do
+context 'When configuration and certificate is present' do
   before do
-    stdout, stderr, status = Open3.capture3(
-                      'openssl', 'req', '-x509',
-                      '-newkey', 'rsa:4096',
-                      '-sha256', '-nodes',
-                      '-subj', '/CN=localhost',
-                      '-days', '1',
-                      '-keyout', '/etc/hitch/key.pem',
-                      '-out', '/etc/hitch/cert.pem'
-                    )
+    _stdout, _stderr, _status = Open3.capture3(
+      'openssl', 'req', '-x509',
+      '-newkey', 'rsa:4096',
+      '-sha256', '-nodes',
+      '-subj', '/CN=localhost',
+      '-days', '1',
+      '-keyout', '/etc/hitch/key.pem',
+      '-out', '/etc/hitch/cert.pem'
+    )
 
     File.write('/etc/hitch/hitch.conf', hitch_conf)
   end
 
   describe command('service hitch start') do
-
     its(:exit_status) { should be 0 }
   end
 
